@@ -1,4 +1,4 @@
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 DB_VERSION = 1
 
@@ -580,7 +580,7 @@ class YEDB():
         else:
             while name.startswith('/'):
                 name = name[1:]
-        return name
+        return name.replace('../', '')
 
     def convert_fmt(self, new_fmt, checksums=True):
         """
